herosdevices.hardware.gamma_vacuum - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.gamma_vacuum

Includes classes for controlling Gamma Vacuum Ltd devices.

## Module Contents

herosdevices.hardware.gamma_vacuum.DEFAULT_OBSERVABLES

class herosdevices.hardware.gamma_vacuum.EthernetSPC(address: str, observables: dict | None = None, *args, **kwargs)

  Bases: `herosdevices.core.templates.TelnetDeviceTemplate`

  Controller for the Gamma vacuum SPC Ion pump controllers with network interface.

  pressure
  current
  voltage
  hv_on
  observables: dict
  address
  connection
  write
  read

class herosdevices.hardware.gamma_vacuum.SerialSPC(address: str, observables: dict | None = None, *args, **kwargs)

  Bases: `herosdevices.core.templates.SerialDeviceTemplate`

  Controller for the Gamma vacuum SPC Ion pump controllers with a serial interface.

  pressure
  current
  voltage
  hv_on
  observables
  address
  connection